@@ -22,7 +22,7 @@ if 'celex' in settings.INSTALLED_APPS:
 from .utils import fetch_buckeye_resource
 from .managers import BulkManager
 
-p = PraatLoader(settings.PRAAT_PATH)
+p = PraatLoader(settings.PRAAT_PATH,debug=True)
 
 class WTManager(BulkManager):
     tbl_name = "buckeyebrowser_wordtoken"
