@@ -3,39 +3,50 @@ Created on 2012-08-24
 
 @author: michael
 '''
-import os,re,math
+import os
+import re
+import math
 
 from celery import task,chord
 from celery.signals import task_success
+from celery.utils.log import get_task_logger
+
 from django.db.models import Q
 from django.core.management import call_command
 
 from .models import WordType,WordToken,Dialog,SegmentType,SegmentToken,Speaker,Category,Underlying
 from .utils import fetch_buckeye_resource,fetch_media_resource,loadFile
 
+logger = get_task_logger(__name__)
 
 Fillers = set(['uh','um','okay','yes','yeah','oh','heh','yknow','um-huh','uh-uh','uh-huh','uh-hum','mm-hmm'])
 
 def loadSegments():
+    logger.info("Loading segments...")
     segs = loadFile(fetch_buckeye_resource("SegmentInfo.txt"))
     ss = []
     for s in segs:
         ss.append(SegmentType(Label=s['Label'],Syllabic=bool(int(s['Syllabic'])),Obstruent=bool(int(s['Obstruent'])),Nasal=bool(int(s['Nasal'])),Vowel=bool(int(s['Vowel']))))
     SegmentType.objects.bulk_create(ss)
+    logger.info("Loaded segments!")
 
 def loadSpeakers():
+    logger.info("Loading speakers...")
     speakers = loadFile(fetch_buckeye_resource("SpeakerInfo.txt"))
     ss = []
     for s in speakers:
         ss.append(Speaker(Number=s['Number'],Age=s['Age'],Gender=s['Gender'],NumFormants=s['NFormants'],Ceiling=s['Ceiling']))
     Speaker.objects.bulk_create(ss)
+    logger.info("Loaded speakers!")
 
 def loadCategories():
+    logger.info("Loading categories...")
     cats = loadFile(fetch_buckeye_resource("CategoryInfo.txt"))
     cs = []
     for s in cats:
         cs.append(Category(Label=s['Label'],Description=s['Description'],CategoryType=s['Type']))
     Category.objects.bulk_create(cs)
+    logger.info("Loaded categories!")
 
 
 
@@ -221,6 +232,7 @@ def processDialogs():
                     wordFiles.append(f)
         for f in wordFiles:
             reorganize(path,f,d)
+        logger.info(str(d))
 
 
 @task()
@@ -231,6 +243,9 @@ def doReset(logfilename):
     loadSpeakers()
     loadDialogs()
     processDialogs()
+    res = chord((loadSegments.s(),loadCategories.s(),loadSpeakers.s()))
+    res = chord((), combineResults.s())()
+    res.get()
 
 @task()
 def combineResults(allout):
@@ -247,6 +262,8 @@ def AnalyzeSpeaker(baseqs,speakNum,form):
     words = baseqs.filter(Dialog__Speaker__Number = speakNum)
     cur = ''
     allout = []
+    logger.info(speakNum)
+    logger.info(str(len(words)))
     #updatelogfile(logfilename, str(len(words)))
     for w in words:
         if not w.isAcceptable():
@@ -310,6 +327,7 @@ def doBasicAnalysis(logfilename,form):
     #    AnalyzeSpeaker.delay(words, s,form)
     res = chord((AnalyzeSpeaker.s(words, s, form) for s in sp), combineResults.s())()
     res.get()
+
 #@task_success.connect(sender=doBasicAnalysis)
 #def consolidateResultFiles():
 #    outs = os.listdir(fetch_buckeye_resource("Results/Buckeye"))
